@@ -1124,7 +1124,7 @@ glide_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
 	      if ((child->data) && GE_IS_WIDGET(child->data) && 
-                  (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
+                  (gtk_widget_get_state (GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
 	          if ((pointer_x >= GTK_WIDGET(child->data)->allocation.x) && 
 	              (pointer_y >= GTK_WIDGET(child->data)->allocation.y) &&
@@ -1172,13 +1172,13 @@ glide_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
 	      if ((child->data) && GE_IS_MENU_ITEM(child->data) && 
-                  (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
+                  (gtk_widget_get_state (GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
                   if ((!GE_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
-                      (!(GTK_WIDGET_REALIZED(GTK_MENU_ITEM(child->data)->submenu) && 
-                         GTK_WIDGET_VISIBLE(GTK_MENU_ITEM(child->data)->submenu) &&
-                         GTK_WIDGET_REALIZED(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
-                         GTK_WIDGET_VISIBLE(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel))))
+                      (!(gtk_widget_get_realized(GTK_MENU_ITEM(child->data)->submenu) && 
+                         gtk_widget_get_visible (GTK_MENU_ITEM(child->data)->submenu) &&
+                         gtk_widget_get_realized(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
+                         gtk_widget_get_visible (GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel))))
 	          {
                     gtk_widget_set_state (GTK_WIDGET(child->data), GTK_STATE_NORMAL);
                   }
@@ -1209,25 +1209,25 @@ glide_gtk2_engine_hack_menu_shell_setup(GtkWidget *widget)
       if (!g_object_get_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_HACK_SET"))
       {
         id = g_signal_connect(G_OBJECT(widget), "motion-notify-event",
-                                             (GtkSignalFunc)glide_gtk2_engine_hack_menu_shell_motion,
+                                             (GCallback)glide_gtk2_engine_hack_menu_shell_motion,
                                              NULL);
                                   
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_MOTION_ID", (gpointer)id);
         
         id = g_signal_connect(G_OBJECT(widget), "leave-notify-event",
-                                             (GtkSignalFunc)glide_gtk2_engine_hack_menu_shell_leave,
+                                             (GCallback)glide_gtk2_engine_hack_menu_shell_leave,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_LEAVE_ID", (gpointer)id);
                                              
         id = g_signal_connect(G_OBJECT(widget), "destroy-event",
-                                             (GtkSignalFunc)glide_gtk2_engine_hack_menu_shell_destroy,
+                                             (GCallback)glide_gtk2_engine_hack_menu_shell_destroy,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_DESTROY_ID", (gpointer)id);
  
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_HACK_SET", (gpointer)1);
         
         id = g_signal_connect(G_OBJECT(widget), "style-set",
-                                             (GtkSignalFunc)glide_gtk2_engine_hack_menu_shell_style_set,
+                                             (GCallback)glide_gtk2_engine_hack_menu_shell_style_set,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "GLIDE_MENU_SHELL_STYLE_SET_ID", (gpointer)id);
       }
